/*
  iowlcd.h
 
  a library to control a LCD 
  connected to the IO-Warrior from www.codemercs.com
  
  written by Christian Vogelgsang <chris@lallafa.de>
  under the GNU Public License Version 2
 
  $Id: iowlcd.h,v 1.2 2004/05/01 19:49:48 cnvogelg Exp $
*/

#ifndef IOWLCD_H
#define IOWLCD_H

#include <usb.h>

/* ========== IOW Low Level ================================================ */

#define IOW_OK    0
#define IOW_ERROR -1

extern int iow_init();
extern void iow_free();
extern usb_dev_handle *iow_open(int id);
extern void iow_close(usb_dev_handle *udh);

/* ========== IOW LCD Basic ================================================ */

#define IOWLCD_BUSY 0x80
#define IOWLCD_ADDR_MASK 0x7F

extern int iowlcd_enable(usb_dev_handle *udh);
extern int iowlcd_disable(usb_dev_handle *udh);
/* status: 0x80=busy bit (IOWLCD_BUSY), 0x7f-> addr (IOWLCD_ADDR_MASK) */
extern int iowlcd_read_status(usb_dev_handle *udh);
extern int iowlcd_display_clear(usb_dev_handle *udh);
extern int iowlcd_return_home(usb_dev_handle *udh);
extern int iowlcd_entry_mode_set(usb_dev_handle *udh,int inc,int shift);
extern int iowlcd_display_on_off(usb_dev_handle *udh,int display,int cursor,int blink);
extern int iowlcd_shift(usb_dev_handle *udh,int display,int right);
extern int iowlcd_set_function(usb_dev_handle *udh,int eight_bit,int two_line,int ten_dots);
extern int iowlcd_set_cgram_addr(usb_dev_handle *udh,int addr);
extern int iowlcd_set_ddram_addr(usb_dev_handle *udh,int addr);
extern int iowlcd_write_data(usb_dev_handle *udh,int len,unsigned char *data);
extern int iowlcd_read_data(usb_dev_handle *udh,int len,unsigned char *data);

/* ========== IOW LCD Tools ================================================ */

extern int iowlcd_setup(usb_dev_handle *udh);
extern int iowlcd_shutdown(usb_dev_handle *udh);
extern int iowlcd_set_pos(usb_dev_handle *udh,int x,int y);
extern int iowlcd_set_text(usb_dev_handle *udh,int x,int y,int len,unsigned char *text);
extern int iowlcd_get_text(usb_dev_handle *udh,int x,int y,int len,unsigned char *text);
extern int iowlcd_load_chars(usb_dev_handle *udh,int offset,int num,unsigned char *bits);

/* draw bars */

#define IOWLCD_HBAR_UNITS 5
#define IOWLCD_VBAR_UNITS 8

extern int iowlcd_load_vbar_chars(usb_dev_handle *udh);
extern int iowlcd_draw_vbar(usb_dev_handle *udh,int x,int y,int h,int val);
extern int iowlcd_draw_vbars(usb_dev_handle *udh,int x,int y,int h,int num,int *vals);
extern int iowlcd_load_hbar_chars(usb_dev_handle *udh);
extern int iowlcd_draw_hbar(usb_dev_handle *udh,int x,int y,int w,int val);
extern int iowlcd_draw_hbars(usb_dev_handle *udh,int x,int y,int w,int num,int *vals);

#endif
