/*
  iowlcd.i
 
  SWIG interface for a library to control a LCD 
  connected to the IO-Warrior from www.codemercs.com
  
  written by Christian Vogelgsang <chris@lallafa.de>
  under the GNU Public License Version 2
 
  $Id: iowlcd.i,v 1.2 2004/05/02 14:33:49 cnvogelg Exp $
*/

%module iowlcd
%{
#include "iowlcd.h"
%}

/* ---------- SWIG Conversion Tools ---------------------------------------- */

/* input buffer conversion:
   (int len,char *data) -> f(..,$data,..) */
%typemap(in) (int len,char *data) {
  STRLEN temp;
  $2 = ($2_ltype) SvPV($input,temp);
  $1 = ($1_ltype) temp;
}

/* output buffer conversion:
   (int len,char *dataout) ->  (..,$dataout,..) = f(..,$len,..) */
%typemap(in,numinputs=1) (int len,char *dataout) {
  if(!SvIOK($input)) 
    croak("Argument $argnum is not an integer");
  $1 = ($1_ltype) SvIV($input);
  $2 = ($2_ltype) malloc($1);
}

%typemap(argout) (int len,char *dataout) {
  $result = sv_newmortal();
  sv_setpvn($result,$2,$1);
  free($2);
  argvi++;
}

/* convert int array */
%typemap(in,numinputs=1) (int num,int *vals) {
  AV *tempav;
  I32 len;
  int i;
  SV **tv;
  if(!SvROK($input))
    croak("Arument $argnum is not a reference");
  if(SvTYPE(SvRV($input)) != SVt_PVAV)
    croak("Argument is not an array");
  tempav = (AV*)SvRV($input);
  len = av_len(tempav) + 1;
  $1 = len;
  $2 = ($2_ltype) malloc(sizeof(int) * len);
  for(i=0;i<len;i++) {
    tv = av_fetch(tempav,i,0);
    if(!SvIOK(*tv))
      croak("No integer in array");
    $2[i] = SvIV(*tv);
  }
}

%typemap(freearg) (int num,int *vals) {
  free($2);
}
  
/* ========== IOW Low Level ================================================ */

#define IOW_OK 0
#define IOW_ERROR -1

int iow_init();
void iow_free();
usb_dev_handle *iow_open(int id);
void iow_close(usb_dev_handle *udh);

/* ========== IOW LCD Basic ================================================ */

#define IOWLCD_BUSY 0x80
#define IOWLCD_ADDR_MASK 0x7F

int iowlcd_enable(usb_dev_handle *udh);
int iowlcd_disable(usb_dev_handle *udh);
int iowlcd_read_status(usb_dev_handle *udh);
int iowlcd_display_clear(usb_dev_handle *udh);
int iowlcd_return_home(usb_dev_handle *udh);
int iowlcd_entry_mode_set(usb_dev_handle *udh,int inc,int shift);
int iowlcd_display_on_off(usb_dev_handle *udh,int display,int cursor,int blink);
int iowlcd_shift(usb_dev_handle *udh,int display,int right);
int iowlcd_set_function(usb_dev_handle *udh,int eight_bit,int two_line,int ten_dots);
int iowlcd_set_cgram_addr(usb_dev_handle *udh,int addr);
int iowlcd_set_ddram_addr(usb_dev_handle *udh,int addr);
int iowlcd_write_data(usb_dev_handle *udh,int len,char *data);
int iowlcd_read_data(usb_dev_handle *udh,int len,char *dataout);

/* ========== IOW LCD Tools ================================================ */

int iowlcd_setup(usb_dev_handle *udh);
int iowlcd_shutdown(usb_dev_handle *udh);
int iowlcd_set_pos(usb_dev_handle *udh,int x,int y);
int iowlcd_set_text(usb_dev_handle *udh,int x,int y,int len,char *data);
int iowlcd_get_text(usb_dev_handle *udh,int x,int y,int len,char *dataout);
int iowlcd_load_chars(usb_dev_handle *udh,int offset,int num,char *bits);

/* draw bars */

#define IOWLCD_HBAR_UNITS 5
#define IOWLCD_VBAR_UNITS 8

int iowlcd_load_vbar_chars(usb_dev_handle *udh);
int iowlcd_draw_vbar(usb_dev_handle *udh,int x,int y,int h,int val);
int iowlcd_draw_vbars(usb_dev_handle *udh,int x,int y,int w,int num,int *vals);
int iowlcd_load_hbar_chars(usb_dev_handle *udh);
int iowlcd_draw_hbar(usb_dev_handle *udh,int x,int y,int w,int val);
int iowlcd_draw_hbars(usb_dev_handle *udh,int x,int y,int w,int num,int *vals);
