/*
  testiowlcd.c
 
  example program for iowlcd library
 
  $Id: testiowlcd.c,v 1.2 2004/05/01 19:49:48 cnvogelg Exp $
*/

#include <string.h>
#include <stdio.h>
#include "iowlcd.h"

void test(usb_dev_handle *udh) 
{
  unsigned char str[20] = "hello, world!!\000\001\002";
  int i;
  
  /* init */
  puts("-- init --");
  if(iowlcd_setup(udh)==IOW_ERROR)
    puts("NO setup");
    
  printf("read_status=0x%02X\n",iowlcd_read_status(udh));
  
  /* define text */
  puts("-- write some text --");
  if(iowlcd_set_text(udh,0,0,16,str)==IOW_ERROR)
    puts("NO set_text");
  printf("string=%s\n",str);
  
  printf("read_status=0x%02X\n",(int)iowlcd_read_status(udh));

  /* read back text */
  puts("-- read back text --");
  memset(str,0,20);
  if(iowlcd_get_text(udh,0,0,16,str)==IOW_ERROR)
    puts("NO get_text");
  printf("string=%s\n",str);

  /* define new char */
  puts("-- hbar test --");
  if(iowlcd_display_clear(udh)==IOW_ERROR)
    puts("NO display_clear");
  if(iowlcd_load_hbar_chars(udh)==IOW_ERROR)
    puts("NO load_hbar_chars");

  puts("count on the display: 0..19");
  for(i=0;i<20;i++) {
    int j = i % (12*IOWLCD_HBAR_UNITS);
    /* draw bar at (8,0) with 12 chars width */
    if(iowlcd_draw_hbar(udh,8,0,12,j)==IOW_ERROR)
      puts("NO draw_hbar");
    
    sprintf(str,"%05d",i);
    if(iowlcd_set_text(udh,0,0,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");
    if(iowlcd_set_text(udh,2,1,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");
    if(iowlcd_set_text(udh,4,2,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");
    if(iowlcd_set_text(udh,6,3,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");    
    
    sleep(1);
  }

  puts("-- vbar test --");
  if(iowlcd_display_clear(udh)==IOW_ERROR)
    puts("NO display_clear");
  if(iowlcd_load_vbar_chars(udh)==IOW_ERROR)
    puts("NO load_hbar_chars");
  
  puts("count on the display: 0..19");
  for(i=0;i<20;i++) {
    int j = i % (4*IOWLCD_VBAR_UNITS);
    int vals[3];
    vals[0] = j;
    vals[1] = 4*8 - 1 - j;
    vals[2] = j / 2;
    /* draw bar at (16,0) with height 4 and 3 values */
    if(iowlcd_draw_vbars(udh,16,0,4, 3,vals)==IOW_ERROR)
      puts("NO draw_vbars");
    
    sprintf(str,"%05d",i);
    if(iowlcd_set_text(udh,0,0,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");
    if(iowlcd_set_text(udh,2,1,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");
    if(iowlcd_set_text(udh,4,2,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");
    if(iowlcd_set_text(udh,6,3,strlen(str),str)==IOW_ERROR)
      puts("NO set_text");    
  
    sleep(1);
  }
  
  
  puts("-- shut down --");
  iowlcd_shutdown(udh);
  puts("ready");
}

int main(int argc, char* argv[]) 
{
  usb_dev_handle *udh;
  
  /* init lib */
  if(iow_init()==0) {
    puts("no warriors found!");
    return 1;
  }
  
  /* open first warrior */
  udh = iow_open(0);
  if(udh==NULL) {
    puts("can't open warrior 0");
    return 1;
  }

  test(udh);
  
  /* close */
  iow_close(udh);
  iow_free(udh);
  return 0;
};
